==> cms-db_v0.8.1.tar.gz: admin/insert.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}
?>
<script type="text/javascript">
<!--

/*
 * The commented out part *could* help with the android 1.6 browser, but
 * apparently it isn't needed in android 1.5 and 2.0 browsers
 */

var field = document.forms[0].content;
/*var selection = new Array();

function updateSelection() {
	var startPos = field.selectionStart;
	var endPos = field.selectionEnd;
	selection[0] = startPos;
	selection[1] = endPos;
	selection[2] = field.value.substring(0, startPos);
	selection[3] = field.value.substring(endPos, field.value.length);
}*/

function insertAtCursorPos(text) {
	//IE support
	if (document.selection) {
		field.focus();
		sel = document.selection.createRange();
		sel.text = text;
		return false;
	}
	//MOZILLA/NETSCAPE support
	else if (field.selectionStart || field.selectionStart == '0') {
		var startPos = field.selectionStart;
		var endPos = field.selectionEnd;
		if (startPos == '0' && endPos == '0') {
			//if (selection[0] == '0' && selection[1] == '0') {
				alert('<?php locale_escape('desc_cantinsert', "'") ?>');
				return false;
			/*} else {
				field.value = selection[2]
							+ text
							+ selection[3];
				return false;
			}*/
		}
		field.value = field.value.substring(0, startPos)
		            + text
		            + field.value.substring(endPos, field.value.length);
		return false;
	} else {
		alert('<?php locale_escape('desc_cantinsert', "'") ?>');
		return false;
	}
}

/*window.onload = function () {
	if (!document.selection) {
		updateSelection();
		field.onchange = updateSelection;
		field.onclick = updateSelection;
		field.onkeyup = updateSelection;
	}
}*/

//-->
</script>
<h2><?php locale('desc_insert-url') ?></h2>
<h3><?php locale('desc_insert-page') ?></h3>
<?php
include('../data/settings/url.inc.php');

function createPageOverview($ordner) {
	global $urlbefore, $urlafter;
	$vorhanden = 0;
	$handle = opendir($ordner);
	while (false !== ($file = readdir($handle))) {
		if($file != '.' && $file != '..') {
			if (is_dir($ordner."/".$file)) {
				$dirs[] = $ordner."/".$file;
				$vorhanden = 1;
			}
		}
	}
	if ($vorhanden == 1) {
		echo '<ul class="linklist">';
	}
	$replace1 = array('%2F','%2C');
	$replace2 = array('/',',');
	if(isset($dirs)) {
		natcasesort($dirs);
		foreach($dirs as $dir) {
			$file = str_replace($ordner."/","",$dir);
			$show = substr($file, 3);
			$show = str_replace("_"," ",$show);
			$show = str_replace("SLASH","/",$show);
			$show = str_replace("AND" ,"&", $show);
			$url = get_full_url(substr($ordner,13).'/'.$file.'/01,Home');
			echo '<li><a href="'.$url.'" onclick="return insertAtCursorPos(\''.$url.'\')">'.$show.'</a>';
			createPageOverview($dir);
			echo '</li>';
		}
	}
	closedir($handle);
	if ($vorhanden == 1) {
		echo '</ul>';
	}
}
createPageOverview("../data/pages");
?>
<h3><?php locale('desc_insert-file') ?></h3>
<?php
function listFiles($folder = '') {
	global $urlabsolute;
	$filelist = array();
	$handle = opendir('../data/files/'.$folder);
	while (false !== ($file = readdir($handle))) {
		if($file != '.' && $file != '..' && $file != '.htaccess') {
			$filelist[] = $file;
		}
	}
	closedir($handle);
	$files = '';
	if (count($filelist) > 0) {
		$files .= '<ul class="linklist">';
		natcasesort($filelist);
		foreach ($filelist as $file) {
			$url = $urlabsolute.'/data/files/'.$folder.$file;
			if (is_file('../data/files/'.$folder.$file)) {
				$files .= '<li><a href="'.$url.'" onclick="return insertAtCursorPos(\''.$url.'\')">'.$file.'</a></li>';
			} elseif (is_dir('../data/files/'.$folder.$file)) {
				$files .= '<li>'.$file.'</li>';
				$files .= listFiles($folder.$file.'/');
			}
		}
		$files .= '</ul>';
	}
	return $files;
}
echo listFiles();
?>

==> cms-db_v0.9.tar.gz: admin/insert.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}
?>
<script type="text/javascript">
<!--

/*
 * The commented out part *could* help with the android 1.6 browser, but
 * apparently it isn't needed in android 1.5 and 2.0 browsers
 */

var field = document.forms[0].content;
/*var selection = new Array();

function updateSelection() {
	var startPos = field.selectionStart;
	var endPos = field.selectionEnd;
	selection[0] = startPos;
	selection[1] = endPos;
	selection[2] = field.value.substring(0, startPos);
	selection[3] = field.value.substring(endPos, field.value.length);
}*/

function insertAtCursorPos(text) {
	//IE support
	if (document.selection) {
		field.focus();
		sel = document.selection.createRange();
		sel.text = text;
		return false;
	}
	//MOZILLA/NETSCAPE support
	else if (field.selectionStart || field.selectionStart == '0') {
		var startPos = field.selectionStart;
		var endPos = field.selectionEnd;
		if (startPos == '0' && endPos == '0') {
			//if (selection[0] == '0' && selection[1] == '0') {
				alert('<?php locale_escape('desc_cantinsert', "'") ?>');
				return false;
			/*} else {
				field.value = selection[2]
							+ text
							+ selection[3];
				return false;
			}*/
		}
		field.value = field.value.substring(0, startPos)
		            + text
		            + field.value.substring(endPos, field.value.length);
		return false;
	} else {
		alert('<?php locale_escape('desc_cantinsert', "'") ?>');
		return false;
	}
}

/*window.onload = function () {
	if (!document.selection) {
		updateSelection();
		field.onchange = updateSelection;
		field.onclick = updateSelection;
		field.onkeyup = updateSelection;
	}
}*/

//-->
</script>
<h2><?php locale('desc_insert-url') ?></h2>
<h3><?php locale('desc_insert-page') ?></h3>
<?php
include('../data/settings/url.inc.php');

function createPageOverview($ordner) {
	global $urlbefore, $urlafter;
	$vorhanden = 0;
	$handle = opendir($ordner);
	while (false !== ($file = readdir($handle))) {
		if($file != '.' && $file != '..') {
			if (is_dir($ordner."/".$file)) {
				$dirs[] = $ordner."/".$file;
				$vorhanden = 1;
			}
		}
	}
	if ($vorhanden == 1) {
		echo '<ul class="linklist">';
	}
	$replace1 = array('%2F','%2C');
	$replace2 = array('/',',');
	if(isset($dirs)) {
		natcasesort($dirs);
		foreach($dirs as $dir) {
			$class = (!isset($class) or $class == 'normal') ? 'alt' : 'normal';
			$file = str_replace($ordner."/","",$dir);
			$show = substr($file, 3);
			$show = str_replace("_"," ",$show);
			$show = str_replace("SLASH","/",$show);
			$show = str_replace("AND" ,"&", $show);
			$url = get_full_url(substr($ordner,13).'/'.$file.'/01,Home');
			echo '<li class="'.$class.'"><a href="'.$url.'" onclick="return insertAtCursorPos(\''.$url.'\')">'.$show.'</a>';
			createPageOverview($dir);
			echo '</li>';
		}
	}
	closedir($handle);
	if ($vorhanden == 1) {
		echo '</ul>';
	}
}
createPageOverview("../data/pages");
?>
<h3><?php locale('desc_insert-file') ?></h3>
<?php
function listFiles($folder = '') {
	global $urlabsolute;
	$filelist = array();
	$handle = opendir('../data/files/'.$folder);
	while (false !== ($file = readdir($handle))) {
		if($file != '.' && $file != '..' && $file != '.htaccess') {
			$filelist[] = $file;
		}
	}
	closedir($handle);
	$files = '';
	if (count($filelist) > 0) {
		$files .= '<ul class="linklist">';
		natcasesort($filelist);
		foreach ($filelist as $file) {
			$class = (!isset($class) or $class == 'normal') ? 'alt' : 'normal';
			$url = $urlabsolute.'/data/files/'.$folder.$file;
			if (is_file('../data/files/'.$folder.$file)) {
				$files .= '<li class="'.$class.'"><a href="'.$url.'" onclick="return insertAtCursorPos(\''.$url.'\')">'.$file.'</a></li>';
			} elseif (is_dir('../data/files/'.$folder.$file)) {
				$files .= '<li class="'.$class.'">'.$file;
				$files .= listFiles($folder.$file.'/');
				$files .= '</li>';
			}
		}
		$files .= '</ul>';
	}
	return $files;
}
echo listFiles();
?>
